"use strict";(self.webpackChunk_infuseai_piperider_ui=self.webpackChunk_infuseai_piperider_ui||[]).push([[836],{1364:function(e,n,t){t.d(n,{Q:function(){return u}});var i=t(1413),r=t(4925),l=t(4190),o=t(9894),s=t(3853),a=t(2737),c=t(184),d=["title","subtitle","iconColor","icon"];function u(e){var n=e.title,t=void 0===n?a.Nj:n,u=e.subtitle,x=void 0===u?a.Nj:u,m=e.iconColor,j=void 0===m?"piperider.500":m,h=e.icon,p=void 0===h?s.aCJ:h,b=(0,r.Z)(e,d);return(0,c.jsxs)(l.xu,(0,i.Z)((0,i.Z)({},b),{},{children:[(0,c.jsx)(l.xv,{color:"gray.500",children:x}),(0,c.jsxs)(l.kC,{alignItems:"center",children:[(0,c.jsx)(o.JO,{mt:1,mr:2,rounded:"md",color:j,as:p,boxSize:6}),(0,c.jsx)(l.X6,{fontSize:24,children:t||a.Nj})]})]}))}},6836:function(e,n,t){t.r(n),t.d(n,{default:function(){return w}});var i=t(9439),r=t(4190),l=t(7094),o=t(8625),s=t(2791),a=t(8039),c=t(8693),d=t(5650),u=t(1573),x=t(8982),m=t(2104),j=t(1892),h=t(8493),p=t(4304),b=t(4494),f=t(7677),g=t(1364),v=t(4749),C=t(5761),S=t(184);function w(e){var n=e.data,t=e.columnName,w=e.tableName;(0,f.jr)("Single Report: Table Column Details"),(0,f.Lp)({eventName:f.mk.PAGE_VIEW,eventProperties:{type:f.ll,page:"column-details-page"}});var y=(0,o.TH)(),_=(0,i.Z)(y,2)[1],R=(0,s.useState)(0),O=(0,i.Z)(R,2),P=O[0],N=O[1];(0,v.n)((function(e){return e.setReportRawData}))({base:n});var k=v.n.getState(),D=k.tableColumnsOnly,A=void 0===D?[]:D,H=k.tableColumnAssertionsOnly,T=A.find((function(e){return(0,i.Z)(e,1)[0]===w})),Z=0===t.length,E=n.tables[w],Q=E.columns[t],z=Q||{},I=z.type,K=z.histogram,J=(0,p.MM)(Q),M=J.backgroundColor,W=J.icon;if(!w||!E||!T)return(0,S.jsx)(a.o,{isSingleReport:!0,children:(0,S.jsx)(h.J,{text:"No profile data found for table name: ".concat(w)})});var Y=(0,f.SR)([null===E||void 0===E?void 0:E.piperider_assertion_result,null===E||void 0===E?void 0:E.dbt_assertion_result]),G=Y.failed,L=Y.total,q=(0,C.gq)(w,t);return(0,S.jsx)(a.o,{isSingleReport:!0,maxHeight:u.t4,children:(0,S.jsxs)(r.rj,{width:"inherit",templateColumns:"1fr 2fr",children:[(0,S.jsx)(r.P4,{colSpan:3,children:(0,S.jsx)(f.Qu,{breadcrumbList:q})}),(0,S.jsx)(r.P4,{overflowY:"scroll",maxHeight:u.t4,children:(0,S.jsx)(m._,{tableColEntry:T,currentTable:w,currentColumn:t,onSelect:function(e){var n=e.tableName,t=e.columnName;N(0),_("/tables/".concat(n,"/columns/").concat(t))},singleOnly:!0})}),Z?(0,S.jsxs)(r.P4,{maxHeight:u.t4,overflowY:"auto",p:10,children:[(0,S.jsx)(g.Q,{title:E.name,subtitle:"Table",mb:5}),(0,S.jsxs)(l.mQ,{defaultIndex:0,children:[(0,S.jsxs)(l.td,{children:[(0,S.jsx)(l.OK,{children:"Overview"}),(0,S.jsx)(l.OK,{children:"Assertions"}),(0,S.jsx)(l.OK,{children:"Schema"})]}),(0,S.jsxs)(l.nP,{children:[(0,S.jsx)(l.x4,{children:(0,S.jsxs)(r.rj,{templateColumns:"1fr 1px 1fr",gap:3,children:[(0,S.jsx)(b.m,{tableDatum:E}),(0,S.jsx)(r.iz,{orientation:"vertical"}),(0,S.jsx)(b.a,{description:E.description})]})}),(0,S.jsxs)(l.x4,{children:[L>0&&(0,S.jsx)(r.kC,{mb:5,children:(0,S.jsx)(f.K_,{total:L,failed:G})}),(0,S.jsx)(f.Ox,{filterString:E.name,comparableAssertions:H,singleOnly:!0,tableSize:"sm"})]}),(0,S.jsx)(l.x4,{children:(0,S.jsx)(f.rH,{baseTableEntryDatum:null===T||void 0===T?void 0:T[1].base,singleOnly:!0,onSelect:function(){}})})]})]})]}):(0,S.jsxs)(r.rj,{templateColumns:"500px 1fr",templateRows:"7em 1fr 1fr",width:"100%",maxHeight:u.t4,overflowY:"auto",children:[(0,S.jsx)(r.P4,{colSpan:2,rowSpan:1,p:9,children:(0,S.jsx)(g.Q,{title:t,subtitle:"Column",p:2,borderBottom:u.dx,icon:W,iconColor:M})}),(0,S.jsx)(r.P4,{p:10,bg:"gray.50",borderRight:u.dx,children:(0,S.jsx)(c.t,{columnDatum:Q,hasAnimation:!0})}),(0,S.jsx)(r.P4,{gridRow:"span 1",minWidth:0,p:9,bg:"gray.50",children:(0,S.jsx)(d.r,{baseColumnDatum:Q,hasAnimation:!0,tabIndex:P,onSelectTab:function(e){return N(e)}})}),(0,S.jsx)(r.P4,{gridRow:"span 1",p:9,bg:"gray.50",borderRight:u.dx,children:(0,p.jl)(I)&&(0,S.jsx)(S.Fragment,{children:(0,S.jsx)(j.E,{columnDatum:Q})})}),(0,p.hG)(I)&&K&&(0,S.jsx)(r.P4,{gridRow:"span 1",p:9,bg:"gray.50",minWidth:"1px",children:(0,S.jsx)(x.M,{columnDatum:Q})})]})]})})}}}]);
//# sourceMappingURL=836.64ed77d5.chunk.js.map